==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

public class DeliverySpecFluentImpl<A extends DeliverySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeliverySpecFluent<A> {

    private String backoffDelay;
    private String backoffPolicy;
    private DestinationBuilder deadLetterSink;
    private Integer retry;

    public DeliverySpecFluentImpl() {
    }

    public DeliverySpecFluentImpl(DeliverySpec instance) {
        this.withBackoffDelay(instance.getBackoffDelay()); 
        this.withBackoffPolicy(instance.getBackoffPolicy()); 
        this.withDeadLetterSink(instance.getDeadLetterSink()); 
        this.withRetry(instance.getRetry()); 
    }

    public String getBackoffDelay() {
        return this.backoffDelay;
    }

    public A withBackoffDelay(String backoffDelay) {
        this.backoffDelay=backoffDelay; return (A) this;
    }

    public Boolean hasBackoffDelay() {
        return this.backoffDelay != null;
    }

    public A withNewBackoffDelay(String arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public A withNewBackoffDelay(StringBuilder arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public A withNewBackoffDelay(StringBuffer arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public String getBackoffPolicy() {
        return this.backoffPolicy;
    }

    public A withBackoffPolicy(String backoffPolicy) {
        this.backoffPolicy=backoffPolicy; return (A) this;
    }

    public Boolean hasBackoffPolicy() {
        return this.backoffPolicy != null;
    }

    public A withNewBackoffPolicy(String arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    public A withNewBackoffPolicy(StringBuilder arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    public A withNewBackoffPolicy(StringBuffer arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildDeadLetterSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getDeadLetterSink() {
        return this.deadLetterSink!=null?this.deadLetterSink.build():null;
    }

    public Destination buildDeadLetterSink() {
        return this.deadLetterSink!=null?this.deadLetterSink.build():null;
    }

    public A withDeadLetterSink(Destination deadLetterSink) {
        _visitables.get("deadLetterSink").remove(this.deadLetterSink);
        if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} return (A) this;
    }

    public Boolean hasDeadLetterSink() {
        return this.deadLetterSink != null;
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSink() {
        return new DeadLetterSinkNestedImpl();
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
        return new DeadLetterSinkNestedImpl(item);
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editDeadLetterSink() {
        return withNewDeadLetterSinkLike(getDeadLetterSink());
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
        return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): new DestinationBuilder().build());
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
        return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): item);
    }

    public Integer getRetry() {
        return this.retry;
    }

    public A withRetry(Integer retry) {
        this.retry=retry; return (A) this;
    }

    public Boolean hasRetry() {
        return this.retry != null;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeliverySpecFluentImpl that = (DeliverySpecFluentImpl) o;
        if (backoffDelay != null ? !backoffDelay.equals(that.backoffDelay) :that.backoffDelay != null) return false;
        if (backoffPolicy != null ? !backoffPolicy.equals(that.backoffPolicy) :that.backoffPolicy != null) return false;
        if (deadLetterSink != null ? !deadLetterSink.equals(that.deadLetterSink) :that.deadLetterSink != null) return false;
        if (retry != null ? !retry.equals(that.retry) :that.retry != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  super.hashCode());
    }

    public class DeadLetterSinkNestedImpl<N> extends DestinationFluentImpl<DeliverySpecFluent.DeadLetterSinkNested<N>> implements DeliverySpecFluent.DeadLetterSinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DestinationBuilder builder;

            DeadLetterSinkNestedImpl(Destination item) {
                this.builder = new DestinationBuilder(this, item);
                        
            }

            DeadLetterSinkNestedImpl() {
                this.builder = new DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) DeliverySpecFluentImpl.this.withDeadLetterSink(builder.build());
            }

            public N endDeadLetterSink() {
                return and();
            }
    }


}

==> knative-model-5.2.0-sources.jar: annotations/io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

public class DeliverySpecFluentImpl<A extends DeliverySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements DeliverySpecFluent<A> {

    private String backoffDelay;
    private String backoffPolicy;
    private DestinationBuilder deadLetterSink;
    private Integer retry;

    public DeliverySpecFluentImpl() {
    }

    public DeliverySpecFluentImpl(DeliverySpec instance) {
        this.withBackoffDelay(instance.getBackoffDelay()); 
        this.withBackoffPolicy(instance.getBackoffPolicy()); 
        this.withDeadLetterSink(instance.getDeadLetterSink()); 
        this.withRetry(instance.getRetry()); 
    }

    public String getBackoffDelay() {
        return this.backoffDelay;
    }

    public A withBackoffDelay(String backoffDelay) {
        this.backoffDelay=backoffDelay; return (A) this;
    }

    public Boolean hasBackoffDelay() {
        return this.backoffDelay != null;
    }

    public A withNewBackoffDelay(String arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public A withNewBackoffDelay(StringBuilder arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public A withNewBackoffDelay(StringBuffer arg1) {
        return (A)withBackoffDelay(new String(arg1));
    }

    public String getBackoffPolicy() {
        return this.backoffPolicy;
    }

    public A withBackoffPolicy(String backoffPolicy) {
        this.backoffPolicy=backoffPolicy; return (A) this;
    }

    public Boolean hasBackoffPolicy() {
        return this.backoffPolicy != null;
    }

    public A withNewBackoffPolicy(String arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    public A withNewBackoffPolicy(StringBuilder arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    public A withNewBackoffPolicy(StringBuffer arg1) {
        return (A)withBackoffPolicy(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildDeadLetterSink instead.
 * @return The buildable object.
 */
@Deprecated public Destination getDeadLetterSink() {
        return this.deadLetterSink!=null?this.deadLetterSink.build():null;
    }

    public Destination buildDeadLetterSink() {
        return this.deadLetterSink!=null?this.deadLetterSink.build():null;
    }

    public A withDeadLetterSink(Destination deadLetterSink) {
        _visitables.get("deadLetterSink").remove(this.deadLetterSink);
        if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} return (A) this;
    }

    public Boolean hasDeadLetterSink() {
        return this.deadLetterSink != null;
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSink() {
        return new DeadLetterSinkNestedImpl();
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
        return new DeadLetterSinkNestedImpl(item);
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editDeadLetterSink() {
        return withNewDeadLetterSinkLike(getDeadLetterSink());
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
        return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): new DestinationBuilder().build());
    }

    public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
        return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): item);
    }

    public Integer getRetry() {
        return this.retry;
    }

    public A withRetry(Integer retry) {
        this.retry=retry; return (A) this;
    }

    public Boolean hasRetry() {
        return this.retry != null;
    }

    public A withNewRetry(String arg1) {
        return (A)withRetry(new Integer(arg1));
    }

    public A withNewRetry(int arg1) {
        return (A)withRetry(new Integer(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        DeliverySpecFluentImpl that = (DeliverySpecFluentImpl) o;
        if (backoffDelay != null ? !backoffDelay.equals(that.backoffDelay) :that.backoffDelay != null) return false;
        if (backoffPolicy != null ? !backoffPolicy.equals(that.backoffPolicy) :that.backoffPolicy != null) return false;
        if (deadLetterSink != null ? !deadLetterSink.equals(that.deadLetterSink) :that.deadLetterSink != null) return false;
        if (retry != null ? !retry.equals(that.retry) :that.retry != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  super.hashCode());
    }

    public class DeadLetterSinkNestedImpl<N> extends DestinationFluentImpl<DeliverySpecFluent.DeadLetterSinkNested<N>> implements DeliverySpecFluent.DeadLetterSinkNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final DestinationBuilder builder;

            DeadLetterSinkNestedImpl(Destination item) {
                this.builder = new DestinationBuilder(this, item);
                        
            }

            DeadLetterSinkNestedImpl() {
                this.builder = new DestinationBuilder(this);
                        
            }

            public N and() {
                return (N) DeliverySpecFluentImpl.this.withDeadLetterSink(builder.build());
            }

            public N endDeadLetterSink() {
                return and();
            }
    }


}
